<!DOCTYPE html>
<html>
<head>
    <title>Marlin v0.97 - Fast REST API Server on redis</title>
    <link rel="stylesheet" href="static/toast.css">
</head>
<body>
    <div class="container">
        <div class="unit span-grid grid">
            <div class="unit one-of-three">
                <img src="static/marlin.jpg" style="width: 100px; float: right">
            </div>
            <div class=" unit two-of-three">
                <h3>Welcome to Marlin</h3><br>
                <div style="font-size: 12px;">Dynamic ReST API on redis</div>
            </div>
        </div>
    </div>
<hr>
<br>
<div class="container">
    <div class="unit">
        <h2>Configuration</h2>
        <span>
        </span>
    </div>
</div>
<div class="container">
    <div class="unit">
        <h2>API Functions</h2>
        <table class="gridtable">
            <thead>
                <td>
                    Method
                </td>
                <td>
                    URL Pattern
                </td>
                <td>
                    Return Value
                </td>
            </thead>
            <tbody>
                <td>
                    Method
                </td>
                <td>
                    URL Pattern
                </td>
                <td>
                    Return Value
                </td>
            </tbody>
        </table>
    </div>
</div>
</body>
</html>